@@ -1,8 +1,7 @@
-
 import os
 import sys
 
-from anki import Collection
+from anki.collection import Collection
 from anki.importing.apkg import AnkiPackageImporter
 
 from mnemocards.utils import create_check_collection_path
@@ -21,4 +20,3 @@ def import_command(apkgs, collection_path=None, profile=None):
         AnkiPackageImporter(col, a).run()
     # Close collection.
     col.close()
-
